@@ -1,4 +1,4 @@
-#pragma ident "$Id: platform.h,v 1.5 2008/08/26 00:23:31 rwg Exp $"
+#pragma ident "$Id: platform.h,v 1.6 2010/03/16 20:52:00 paulf Exp $"
 /* --------------------------------------------------------------------
  Program  : Any
  Task     : Any.
@@ -13,7 +13,7 @@
             (214) 353-0609 Voice, (214) 353-9659 Fax, info@reftek.com
  Copyright: (c) 1997 Refraction Technology, Inc. - All Rights Reserved.
  Notes    :
- $Revision: 1.5 $
+ $Revision: 1.6 $
  $Logfile : R:/cpu68000/rt422/struct/version.h_v  $
  Revised  :
   17 Aug 1998  ---- (RLB) First effort.
@@ -58,6 +58,16 @@
 #   endif
 #endif
 
+#ifdef _MACOSX
+#   undef _MACOSX
+#   ifndef unix
+#       define unix
+#   endif
+#   ifndef LINUX
+#       define LINUX
+#   endif
+#endif
+
 #ifdef _LINUX
 #   ifndef LINUX
 #       define LINUX
@@ -453,6 +463,9 @@ int errno;
 /* Revision History
  *
  * $Log: platform.h,v $
+ * Revision 1.6  2010/03/16 20:52:00  paulf
+ * minor change to platform.h and makefile.ux to get this to compile on MACOSX
+ *
  * Revision 1.5  2008/08/26 00:23:31  rwg
  * fix build on x86_64...?
  *
